#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                   gi-pango
version:                1.0.30
visibility:             public
id:                     gi-pango-1.0.30-Fwxfv4aXOG3KzAMI56Gmfo
key:                    gi-pango-1.0.30-Fwxfv4aXOG3KzAMI56Gmfo
license:                LGPL-2.1-only
maintainer:             Iñaki García Etxebarria
author:                 Iñaki García Etxebarria
homepage:               https://github.com/haskell-gi/haskell-gi
synopsis:               Pango bindings
description:            Bindings for Pango, autogenerated by haskell-gi.
category:               Bindings
abi:                    100c3442a40e5592cc4f05c24c13713e
exposed:                True
exposed-modules:
    GI.Pango GI.Pango.Callbacks GI.Pango.Config GI.Pango.Constants
    GI.Pango.Enums GI.Pango.Flags GI.Pango.Functions GI.Pango.Objects
    GI.Pango.Objects.Context GI.Pango.Objects.Coverage
    GI.Pango.Objects.Font GI.Pango.Objects.FontFace
    GI.Pango.Objects.FontFamily GI.Pango.Objects.FontMap
    GI.Pango.Objects.Fontset GI.Pango.Objects.FontsetSimple
    GI.Pango.Objects.Layout GI.Pango.Objects.Renderer GI.Pango.Structs
    GI.Pango.Structs.Analysis GI.Pango.Structs.AttrClass
    GI.Pango.Structs.AttrColor GI.Pango.Structs.AttrFloat
    GI.Pango.Structs.AttrFontDesc GI.Pango.Structs.AttrFontFeatures
    GI.Pango.Structs.AttrInt GI.Pango.Structs.AttrIterator
    GI.Pango.Structs.AttrLanguage GI.Pango.Structs.AttrList
    GI.Pango.Structs.AttrShape GI.Pango.Structs.AttrSize
    GI.Pango.Structs.AttrString GI.Pango.Structs.Attribute
    GI.Pango.Structs.Color GI.Pango.Structs.FontDescription
    GI.Pango.Structs.FontMetrics GI.Pango.Structs.GlyphGeometry
    GI.Pango.Structs.GlyphInfo GI.Pango.Structs.GlyphItem
    GI.Pango.Structs.GlyphItemIter GI.Pango.Structs.GlyphString
    GI.Pango.Structs.GlyphVisAttr GI.Pango.Structs.Item
    GI.Pango.Structs.Language GI.Pango.Structs.LayoutIter
    GI.Pango.Structs.LayoutLine GI.Pango.Structs.LogAttr
    GI.Pango.Structs.Matrix GI.Pango.Structs.Rectangle
    GI.Pango.Structs.ScriptIter GI.Pango.Structs.TabArray

import-dirs:            /usr/lib/ghc-9.6.6/site-local/gi-pango-1.0.30
library-dirs:
    /usr/lib/ghc-9.6.6/site-local/gi-pango-1.0.30 /usr/lib

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/gi-pango-1.0.30 /usr/lib

dynamic-library-dirs:   /usr/lib /usr/lib
data-dir:               /usr/share/haskell-gi-pango
hs-libraries:           HSgi-pango-1.0.30-Fwxfv4aXOG3KzAMI56Gmfo
extra-libraries:        pango-1.0 harfbuzz gobject-2.0 glib-2.0
extra-libraries-static:
    pango-1.0 m harfbuzz m graphite2 gio-2.0 gobject-2.0 ffi
    gmodule-2.0 glib-2.0 atomic m pcre2-8 pthread mount blkid systemd
    fribidi thai datrie Xft cairo m dl fontconfig m expat m freetype dl
    bz2 png16 m m z brotlidec brotlicommon Xext Xrender X11 pthread
    xcb-render xcb-shm xcb Xau Xdmcp pixman-1 m sysprof-capture-4

include-dirs:
    /usr/include/pango-1.0 /usr/include/harfbuzz /usr/include
    /usr/include/glib-2.0 /usr/lib/glib-2.0/include
    /usr/include/libmount /usr/include/blkid /usr/include/fribidi
    /usr/include/cairo /usr/include/freetype2 /usr/include/libpng16
    /usr/include/pixman-1 /usr/include/sysprof-6

depends:
    base-4.18.2.1 bytestring-0.11.5.3 containers-0.6.7
    gi-gio-2.0.38-F2Yp7EQ0YWH1xVhIDvkWzT
    gi-glib-2.0.30-IcaIp2l70zcG5halkn5IYW
    gi-gobject-2.0.31-AjkEs2jHIFqLqMLDVpEg8j
    gi-harfbuzz-0.0.10-BlqYqiK4eRF86YzUXY7CLM
    haskell-gi-0.26.16-DMf6pFdl4p9HucCsiMRxs
    haskell-gi-base-0.26.9-DWjNTqMCnmO6mDRH5jgSPC
    haskell-gi-overloading-1.0-6w3IXGDooXgu3RA2LfTuf text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:     /usr/share/doc/haskell-gi-pango/html/gi-pango.haddock
haddock-html:           /usr/share/doc/haskell-gi-pango/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

